
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '32.2.0',
    'branch_nick': 'release-32-LTS',
    'revision_id': '6a3a81771290d0309cb3c147588581c0e5944796',
    'revno': 12613
}
